IntegerWithUnits : A whole number dimension and its unit of measurement. For example, this can represent 100 pixels.
Fields
value: i32The dimension value.
units: StringThe unit of measurement.
Implementations
sourceimpl IntegerWithUnits
impl IntegerWithUnits
sourcepub fn new(value: i32, units: String) -> IntegerWithUnits
pub fn new(value: i32, units: String) -> IntegerWithUnits
A whole number dimension and its unit of measurement. For example, this can represent 100 pixels.